@@ -27,10 +27,6 @@ int main(int argc, char **argv)
 {
 #ifdef HAVE_FACILE
     caml_startup(argv);
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kalzium");
